@@ -139,6 +139,17 @@ def testConsistencyChecks():
     x = a.consistencyCheckLEDET()
     print(x)
 
+def testvQ():
+    nameFileLEDET = "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\D2\D2_0.xlsx"
+    a = ParametersLEDET()
+    a.readLEDETExcel(nameFileLEDET)
+    Sw = MinMaxSweep(a, 1)
+    I00 = 12330
+    Sw.addCurrentSweep(I00, 1)
+    nameMagnet = "D2"
+    Sw.prepareSimulation(nameMagnet, "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\D2",
+                         ROXIE_File="C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\D2\D2_All_WithIron_WithSelfField.map2d")
+
 # testConsistencyChecks()
 # test_readLEDETExcel()
 # test_setgetAttributes()
@@ -146,7 +157,8 @@ def testConsistencyChecks():
 # test_SetUpSimulations()
 # test_EvaluateSimulations()
 
-CompleteRun()
+# CompleteRun()
+testvQ()
 
 # a = ParametersLEDET()
 # a.readLEDETExcel(testfile7)
