@@ -1,5 +1,6 @@
 import sys
 import matplotlib.pyplot as plt
+import os
 
 
 def progressBar(value, endvalue, bar_length=20):
@@ -65,11 +66,15 @@ def makeCopyFile(nameInputFile: str, nameOutputFile: str):
         # >>> 					Status: [----->              ] 30%
 
     """
-    f = open(nameOutputFile, 'w')
-    with open(nameInputFile) as inputfile:
-        for line in inputfile:
-            f.write(line)
-    f.close()
+    if os.path.isfile(nameInputFile):
+        f = open(nameOutputFile, 'w')
+        with open(nameInputFile) as inputfile:
+            for line in inputfile:
+                f.write(line)
+        f.close()
+    else:
+        print("Copying ", str(nameInputFile), " failed. Not existing.")
+        return
 
 
 def displayWaitAndClose(waitTimeBeforeMessage: float, waitTimeAfterMessage: float = 0):
